# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.signal_signal_overview_response import SignalSignalOverviewResponse

class TestSignalSignalOverviewResponse(unittest.TestCase):
    """SignalSignalOverviewResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SignalSignalOverviewResponse:
        """Test SignalSignalOverviewResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SignalSignalOverviewResponse`
        """
        model = SignalSignalOverviewResponse()
        if include_optional:
            return SignalSignalOverviewResponse(
                by_client = [
                    neurograph.v1.models.signal/client_signal_summary.signal.ClientSignalSummary(
                        avg_data_completeness = 1.337, 
                        client_uid = '', 
                        conversion_coverage = 1.337, 
                        high_intent_pct = 1.337, 
                        high_intent_visitors = 56, 
                        low_intent_visitors = 56, 
                        medium_intent_visitors = 56, 
                        org_uid = '', 
                        pageview_conversions = 56, 
                        persona_coverage = 1.337, 
                        purchase_conversions = 56, 
                        total_conversions = 56, 
                        total_visitors = 56, )
                    ],
                cached = True,
                daily_conversions = [
                    neurograph.v1.models.signal/daily_conversion_metrics.signal.DailyConversionMetrics(
                        api_success_count = 56, 
                        api_success_rate = 1.337, 
                        data_completeness = 1.337, 
                        date = '', 
                        pageview_conversions = 56, 
                        purchase_conversions = 56, 
                        total_conversions = 56, 
                        with_persona = 56, 
                        with_visitor_id = 56, )
                    ],
                daily_intent = [
                    neurograph.v1.models.signal/daily_intent_metrics.signal.DailyIntentMetrics(
                        avg_attention_seconds = 1.337, 
                        avg_product_views = 1.337, 
                        date = '', 
                        high_intent_pct = 1.337, 
                        high_intent_visitors = 56, 
                        low_intent_pct = 1.337, 
                        low_intent_visitors = 56, 
                        match_rate_pct = 1.337, 
                        medium_intent_pct = 1.337, 
                        medium_intent_visitors = 56, 
                        total_visitors = 56, 
                        visitors_with_hem = 56, )
                    ],
                date_range = neurograph.v1.models.signal/date_range.signal.DateRange(
                    end_date = '', 
                    start_date = '', ),
                error = '',
                query_time_ms = 56,
                totals = neurograph.v1.models.signal/signal_overview_totals.signal.SignalOverviewTotals(
                    avg_match_rate_pct = 1.337, 
                    conversions = neurograph.v1.models.signal/conversion_totals.signal.ConversionTotals(
                        api_success_rate = 1.337, 
                        avg_data_completeness = 1.337, 
                        persona_coverage = 1.337, 
                        total_conversions = 56, 
                        total_pageview_conversions = 56, 
                        total_purchase_conversions = 56, 
                        visitor_id_coverage = 1.337, ), 
                    intent_distribution = neurograph.v1.models.signal/intent_distribution.signal.IntentDistribution(
                        high_intent = 56, 
                        high_pct = 1.337, 
                        low_intent = 56, 
                        low_pct = 1.337, 
                        medium_intent = 56, 
                        medium_pct = 1.337, ), 
                    total_visitors = 56, 
                    total_with_hem = 56, )
            )
        else:
            return SignalSignalOverviewResponse(
        )
        """

    def testSignalSignalOverviewResponse(self):
        """Test SignalSignalOverviewResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_category_performance_row import ReportingCategoryPerformanceRow

class TestReportingCategoryPerformanceRow(unittest.TestCase):
    """ReportingCategoryPerformanceRow unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingCategoryPerformanceRow:
        """Test ReportingCategoryPerformanceRow
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingCategoryPerformanceRow`
        """
        model = ReportingCategoryPerformanceRow()
        if include_optional:
            return ReportingCategoryPerformanceRow(
                account_avg_affinity = 1.337,
                account_avg_conv_rate = 1.337,
                account_avg_purchases = 1.337,
                account_purchase_pct = 1.337,
                affinity_delta = 1.337,
                aov = 1.337,
                avg_affinity_score = 1.337,
                category_name = '',
                conv_rate_delta = 1.337,
                conversion_rate = 1.337,
                engagement_level = '',
                is_top_category = True,
                persona_purchase_pct = 1.337,
                purchase_pct_delta = 1.337,
                purchases = 56,
                relative_performance = 1.337,
                rpv = 1.337,
                total_visitors = 56
            )
        else:
            return ReportingCategoryPerformanceRow(
        )
        """

    def testReportingCategoryPerformanceRow(self):
        """Test ReportingCategoryPerformanceRow"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from neurograph.v1.models.admin_permission_response import AdminPermissionResponse
from neurograph.v1.models.admin_reset_password_request import AdminResetPasswordRequest
from neurograph.v1.models.admin_reset_password_response import AdminResetPasswordResponse
from neurograph.v1.models.admin_set_permission_request import AdminSetPermissionRequest
from neurograph.v1.models.admin_upsert_user_request import AdminUpsertUserRequest
from neurograph.v1.models.admin_upsert_user_response import AdminUpsertUserResponse
from neurograph.v1.models.admin_user import AdminUser
from neurograph.v1.models.admin_user_detail_response import AdminUserDetailResponse
from neurograph.v1.models.admin_users_get_many_response import AdminUsersGetManyResponse
from neurograph.v1.models.admin_users_org_response import AdminUsersOrgResponse
from neurograph.v1.models.auth_service_token_request import AuthServiceTokenRequest
from neurograph.v1.models.auth_service_token_response import AuthServiceTokenResponse
from neurograph.v1.models.auth_test_service_token_request import AuthTestServiceTokenRequest
from neurograph.v1.models.auth_test_service_token_response import AuthTestServiceTokenResponse
from neurograph.v1.models.auth_test_token_response import AuthTestTokenResponse
from neurograph.v1.models.client_client import ClientClient
from neurograph.v1.models.client_delete_metadata_request import ClientDeleteMetadataRequest
from neurograph.v1.models.client_get_detail_response import ClientGetDetailResponse
from neurograph.v1.models.client_get_many_response import ClientGetManyResponse
from neurograph.v1.models.client_healthcheck_create_request import ClientHealthcheckCreateRequest
from neurograph.v1.models.client_healthcheck_response import ClientHealthcheckResponse
from neurograph.v1.models.client_healthcheck_rollup_response import ClientHealthcheckRollupResponse
from neurograph.v1.models.client_info import ClientInfo
from neurograph.v1.models.client_kpi import ClientKpi
from neurograph.v1.models.client_match_criteria_row_in_db import ClientMatchCriteriaRowInDb
from neurograph.v1.models.client_metadata import ClientMetadata
from neurograph.v1.models.client_metadata_request import ClientMetadataRequest
from neurograph.v1.models.client_metadata_response import ClientMetadataResponse
from neurograph.v1.models.client_organization_brand import ClientOrganizationBrand
from neurograph.v1.models.client_organization_detail import ClientOrganizationDetail
from neurograph.v1.models.client_persona import ClientPersona
from neurograph.v1.models.client_persona_assignment_stats import ClientPersonaAssignmentStats
from neurograph.v1.models.client_persona_assignment_stats_response import ClientPersonaAssignmentStatsResponse
from neurograph.v1.models.client_persona_factor import ClientPersonaFactor
from neurograph.v1.models.client_persona_insight import ClientPersonaInsight
from neurograph.v1.models.client_persona_personality_trait import ClientPersonaPersonalityTrait
from neurograph.v1.models.client_personas_response import ClientPersonasResponse
from neurograph.v1.models.client_probe import ClientProbe
from neurograph.v1.models.client_probe_todo_row import ClientProbeTodoRow
from neurograph.v1.models.client_query import ClientQuery
from neurograph.v1.models.client_slack_message_request import ClientSlackMessageRequest
from neurograph.v1.models.client_slack_message_response import ClientSlackMessageResponse
from neurograph.v1.models.client_supplemental_prompt import ClientSupplementalPrompt
from neurograph.v1.models.client_system_healthcheck_detail_response import ClientSystemHealthcheckDetailResponse
from neurograph.v1.models.client_system_healthcheck_history_response import ClientSystemHealthcheckHistoryResponse
from neurograph.v1.models.client_system_healthcheck_latest_response import ClientSystemHealthcheckLatestResponse
from neurograph.v1.models.client_system_healthcheck_query_result import ClientSystemHealthcheckQueryResult
from neurograph.v1.models.client_system_healthcheck_snapshot import ClientSystemHealthcheckSnapshot
from neurograph.v1.models.client_trigger_probe_response import ClientTriggerProbeResponse
from neurograph.v1.models.client_url_snapshot_response import ClientURLSnapshotResponse
from neurograph.v1.models.client_upsert_request import ClientUpsertRequest
from neurograph.v1.models.client_upsert_response import ClientUpsertResponse
from neurograph.v1.models.client_url_row import ClientUrlRow
from neurograph.v1.models.client_url_snapshot_row import ClientUrlSnapshotRow
from neurograph.v1.models.client_url_upsert_request import ClientUrlUpsertRequest
from neurograph.v1.models.client_url_upsert_response import ClientUrlUpsertResponse
from neurograph.v1.models.client_urls_response import ClientUrlsResponse
from neurograph.v1.models.client_workbench_config import ClientWorkbenchConfig
from neurograph.v1.models.dagster_info import DagsterInfo
from neurograph.v1.models.dagster_log_create_request import DagsterLogCreateRequest
from neurograph.v1.models.dagster_log_create_response import DagsterLogCreateResponse
from neurograph.v1.models.dagster_log_get_response import DagsterLogGetResponse
from neurograph.v1.models.db_account_organization_brand import DbAccountOrganizationBrand
from neurograph.v1.models.db_client_url import DbClientUrl
from neurograph.v1.models.db_knowledge_customer import DbKnowledgeCustomer
from neurograph.v1.models.db_knowledge_order import DbKnowledgeOrder
from neurograph.v1.models.db_knowledge_product import DbKnowledgeProduct
from neurograph.v1.models.db_knowledge_store import DbKnowledgeStore
from neurograph.v1.models.db_my_client import DbMyClient
from neurograph.v1.models.db_my_org import DbMyOrg
from neurograph.v1.models.db_persona_factor import DbPersonaFactor
from neurograph.v1.models.db_persona_factor_create_params import DbPersonaFactorCreateParams
from neurograph.v1.models.db_persona_match_criterium import DbPersonaMatchCriterium
from neurograph.v1.models.db_pixel_snippet import DbPixelSnippet
from neurograph.v1.models.db_user_client_role import DbUserClientRole
from neurograph.v1.models.db_user_in_db import DbUserInDb
from neurograph.v1.models.db_user_org_role import DbUserOrgRole
from neurograph.v1.models.db_user_role import DbUserRole
from neurograph.v1.models.knowledge_assertion import KnowledgeAssertion
from neurograph.v1.models.knowledge_assertion_create_request import KnowledgeAssertionCreateRequest
from neurograph.v1.models.knowledge_assertion_list_response import KnowledgeAssertionListResponse
from neurograph.v1.models.knowledge_assertion_query import KnowledgeAssertionQuery
from neurograph.v1.models.knowledge_assertion_response import KnowledgeAssertionResponse
from neurograph.v1.models.knowledge_customer_query import KnowledgeCustomerQuery
from neurograph.v1.models.knowledge_customer_response import KnowledgeCustomerResponse
from neurograph.v1.models.knowledge_enrichment_artifact import KnowledgeEnrichmentArtifact
from neurograph.v1.models.knowledge_enrichment_artifact_create_request import KnowledgeEnrichmentArtifactCreateRequest
from neurograph.v1.models.knowledge_enrichment_artifact_list_response import KnowledgeEnrichmentArtifactListResponse
from neurograph.v1.models.knowledge_enrichment_artifact_response import KnowledgeEnrichmentArtifactResponse
from neurograph.v1.models.knowledge_enrichment_artifact_update_output_request import KnowledgeEnrichmentArtifactUpdateOutputRequest
from neurograph.v1.models.knowledge_enrichment_artifact_update_status_request import KnowledgeEnrichmentArtifactUpdateStatusRequest
from neurograph.v1.models.knowledge_enrichment_query import KnowledgeEnrichmentQuery
from neurograph.v1.models.knowledge_entity import KnowledgeEntity
from neurograph.v1.models.knowledge_entity_create_request import KnowledgeEntityCreateRequest
from neurograph.v1.models.knowledge_entity_create_response import KnowledgeEntityCreateResponse
from neurograph.v1.models.knowledge_entity_err_row import KnowledgeEntityErrRow
from neurograph.v1.models.knowledge_entity_extra import KnowledgeEntityExtra
from neurograph.v1.models.knowledge_entity_get_many_response import KnowledgeEntityGetManyResponse
from neurograph.v1.models.knowledge_entity_in_db import KnowledgeEntityInDb
from neurograph.v1.models.knowledge_entity_relations import KnowledgeEntityRelations
from neurograph.v1.models.knowledge_entity_schema import KnowledgeEntitySchema
from neurograph.v1.models.knowledge_entity_schema_row import KnowledgeEntitySchemaRow
from neurograph.v1.models.knowledge_entity_schema_upsert_request import KnowledgeEntitySchemaUpsertRequest
from neurograph.v1.models.knowledge_entity_schemas_response import KnowledgeEntitySchemasResponse
from neurograph.v1.models.knowledge_entity_schemas_upsert_response import KnowledgeEntitySchemasUpsertResponse
from neurograph.v1.models.knowledge_entity_type_response import KnowledgeEntityTypeResponse
from neurograph.v1.models.knowledge_entity_type_row import KnowledgeEntityTypeRow
from neurograph.v1.models.knowledge_entity_type_upsert_request import KnowledgeEntityTypeUpsertRequest
from neurograph.v1.models.knowledge_entity_type_upsert_row import KnowledgeEntityTypeUpsertRow
from neurograph.v1.models.knowledge_entity_upsert_request import KnowledgeEntityUpsertRequest
from neurograph.v1.models.knowledge_entity_upsert_response import KnowledgeEntityUpsertResponse
from neurograph.v1.models.knowledge_ingest_raw_request import KnowledgeIngestRawRequest
from neurograph.v1.models.knowledge_ingest_raw_response import KnowledgeIngestRawResponse
from neurograph.v1.models.knowledge_ingest_raw_row import KnowledgeIngestRawRow
from neurograph.v1.models.knowledge_kind_response import KnowledgeKindResponse
from neurograph.v1.models.knowledge_order_query import KnowledgeOrderQuery
from neurograph.v1.models.knowledge_order_response import KnowledgeOrderResponse
from neurograph.v1.models.knowledge_product import KnowledgeProduct
from neurograph.v1.models.knowledge_product_query import KnowledgeProductQuery
from neurograph.v1.models.knowledge_product_response import KnowledgeProductResponse
from neurograph.v1.models.knowledge_product_upsert_request import KnowledgeProductUpsertRequest
from neurograph.v1.models.knowledge_product_upsert_response import KnowledgeProductUpsertResponse
from neurograph.v1.models.knowledge_query import KnowledgeQuery
from neurograph.v1.models.knowledge_store_query import KnowledgeStoreQuery
from neurograph.v1.models.knowledge_store_response import KnowledgeStoreResponse
from neurograph.v1.models.lookup_env import LookupEnv
from neurograph.v1.models.lookup_language import LookupLanguage
from neurograph.v1.models.lookup_language_response import LookupLanguageResponse
from neurograph.v1.models.lookup_lookup_environments_response import LookupLookupEnvironmentsResponse
from neurograph.v1.models.lookup_role import LookupRole
from neurograph.v1.models.lookup_roles_response import LookupRolesResponse
from neurograph.v1.models.lookup_state import LookupState
from neurograph.v1.models.lookup_state_response import LookupStateResponse
from neurograph.v1.models.lookup_states_response import LookupStatesResponse
from neurograph.v1.models.lookup_sync_snippets_response import LookupSyncSnippetsResponse
from neurograph.v1.models.lookup_uid import LookupUid
from neurograph.v1.models.lookup_uids_response import LookupUidsResponse
from neurograph.v1.models.me_my_profile_response import MeMyProfileResponse
from neurograph.v1.models.openai_accessibility_info import OpenaiAccessibilityInfo
from neurograph.v1.models.openai_brand_analysis import OpenaiBrandAnalysis
from neurograph.v1.models.openai_brand_colors import OpenaiBrandColors
from neurograph.v1.models.openai_generated_brand import OpenaiGeneratedBrand
from neurograph.v1.models.opportunities_opportunity_create_request import OpportunitiesOpportunityCreateRequest
from neurograph.v1.models.opportunities_opportunity_delete_response import OpportunitiesOpportunityDeleteResponse
from neurograph.v1.models.opportunities_opportunity_list_response import OpportunitiesOpportunityListResponse
from neurograph.v1.models.opportunities_opportunity_response import OpportunitiesOpportunityResponse
from neurograph.v1.models.opportunities_opportunity_update_request import OpportunitiesOpportunityUpdateRequest
from neurograph.v1.models.organizations_apply_preset_request import OrganizationsApplyPresetRequest
from neurograph.v1.models.organizations_apply_preset_response import OrganizationsApplyPresetResponse
from neurograph.v1.models.organizations_brand import OrganizationsBrand
from neurograph.v1.models.organizations_brand_detail_response import OrganizationsBrandDetailResponse
from neurograph.v1.models.organizations_brand_generation_request import OrganizationsBrandGenerationRequest
from neurograph.v1.models.organizations_brand_generation_response import OrganizationsBrandGenerationResponse
from neurograph.v1.models.organizations_brand_history_detail_response import OrganizationsBrandHistoryDetailResponse
from neurograph.v1.models.organizations_brand_history_item import OrganizationsBrandHistoryItem
from neurograph.v1.models.organizations_brand_history_list_response import OrganizationsBrandHistoryListResponse
from neurograph.v1.models.organizations_brand_rollback_request import OrganizationsBrandRollbackRequest
from neurograph.v1.models.organizations_brand_rollback_response import OrganizationsBrandRollbackResponse
from neurograph.v1.models.organizations_brand_upsert_request import OrganizationsBrandUpsertRequest
from neurograph.v1.models.organizations_component_config import OrganizationsComponentConfig
from neurograph.v1.models.organizations_create_request import OrganizationsCreateRequest
from neurograph.v1.models.organizations_delete_metadata_request import OrganizationsDeleteMetadataRequest
from neurograph.v1.models.organizations_delete_metadata_response import OrganizationsDeleteMetadataResponse
from neurograph.v1.models.organizations_detail_response import OrganizationsDetailResponse
from neurograph.v1.models.organizations_gamma_block_settings import OrganizationsGammaBlockSettings
from neurograph.v1.models.organizations_gamma_button_settings import OrganizationsGammaButtonSettings
from neurograph.v1.models.organizations_gamma_card_settings import OrganizationsGammaCardSettings
from neurograph.v1.models.organizations_gamma_color_settings import OrganizationsGammaColorSettings
from neurograph.v1.models.organizations_gamma_design_settings import OrganizationsGammaDesignSettings
from neurograph.v1.models.organizations_gamma_font_settings import OrganizationsGammaFontSettings
from neurograph.v1.models.organizations_gamma_theme_request import OrganizationsGammaThemeRequest
from neurograph.v1.models.organizations_gamma_theme_response import OrganizationsGammaThemeResponse
from neurograph.v1.models.organizations_gamma_theme_settings import OrganizationsGammaThemeSettings
from neurograph.v1.models.organizations_generate_tokens_request import OrganizationsGenerateTokensRequest
from neurograph.v1.models.organizations_generate_tokens_response import OrganizationsGenerateTokensResponse
from neurograph.v1.models.organizations_generation_metadata import OrganizationsGenerationMetadata
from neurograph.v1.models.organizations_get_branding_tokens_response import OrganizationsGetBrandingTokensResponse
from neurograph.v1.models.organizations_get_many_response import OrganizationsGetManyResponse
from neurograph.v1.models.organizations_metadata import OrganizationsMetadata
from neurograph.v1.models.organizations_metadata_request import OrganizationsMetadataRequest
from neurograph.v1.models.organizations_metadata_response import OrganizationsMetadataResponse
from neurograph.v1.models.organizations_organization import OrganizationsOrganization
from neurograph.v1.models.organizations_organization_set_workbench_request import OrganizationsOrganizationSetWorkbenchRequest
from neurograph.v1.models.organizations_organization_set_workbench_response import OrganizationsOrganizationSetWorkbenchResponse
from neurograph.v1.models.organizations_organization_update_request import OrganizationsOrganizationUpdateRequest
from neurograph.v1.models.organizations_preset_recommendation import OrganizationsPresetRecommendation
from neurograph.v1.models.organizations_preview_branding_request import OrganizationsPreviewBrandingRequest
from neurograph.v1.models.organizations_preview_branding_response import OrganizationsPreviewBrandingResponse
from neurograph.v1.models.organizations_recommend_presets_response import OrganizationsRecommendPresetsResponse
from neurograph.v1.models.organizations_screenshot_url_request import OrganizationsScreenshotURLRequest
from neurograph.v1.models.organizations_screenshot_url_response import OrganizationsScreenshotURLResponse
from neurograph.v1.models.organizations_spacing_config import OrganizationsSpacingConfig
from neurograph.v1.models.organizations_test_accessibility_request import OrganizationsTestAccessibilityRequest
from neurograph.v1.models.organizations_test_accessibility_response import OrganizationsTestAccessibilityResponse
from neurograph.v1.models.organizations_theme_preset_create_request import OrganizationsThemePresetCreateRequest
from neurograph.v1.models.organizations_theme_preset_list_response import OrganizationsThemePresetListResponse
from neurograph.v1.models.organizations_theme_preset_response import OrganizationsThemePresetResponse
from neurograph.v1.models.organizations_theme_preset_update_request import OrganizationsThemePresetUpdateRequest
from neurograph.v1.models.organizations_typography_config import OrganizationsTypographyConfig
from neurograph.v1.models.organizations_validate_branding_request import OrganizationsValidateBrandingRequest
from neurograph.v1.models.organizations_validate_branding_response import OrganizationsValidateBrandingResponse
from neurograph.v1.models.organizations_workbench_config import OrganizationsWorkbenchConfig
from neurograph.v1.models.personas_factor_create_request import PersonasFactorCreateRequest
from neurograph.v1.models.personas_factor_create_response import PersonasFactorCreateResponse
from neurograph.v1.models.personas_factor_delete_response import PersonasFactorDeleteResponse
from neurograph.v1.models.personas_factor_row import PersonasFactorRow
from neurograph.v1.models.personas_factor_update_request import PersonasFactorUpdateRequest
from neurograph.v1.models.personas_factor_update_response import PersonasFactorUpdateResponse
from neurograph.v1.models.personas_get_latest_persona_instance_request import PersonasGetLatestPersonaInstanceRequest
from neurograph.v1.models.personas_get_persona_instance_response import PersonasGetPersonaInstanceResponse
from neurograph.v1.models.personas_insight_create_request import PersonasInsightCreateRequest
from neurograph.v1.models.personas_insight_create_response import PersonasInsightCreateResponse
from neurograph.v1.models.personas_instance_create_request import PersonasInstanceCreateRequest
from neurograph.v1.models.personas_instance_create_response import PersonasInstanceCreateResponse
from neurograph.v1.models.personas_instance_delete_many_request import PersonasInstanceDeleteManyRequest
from neurograph.v1.models.personas_instance_delete_many_response import PersonasInstanceDeleteManyResponse
from neurograph.v1.models.personas_instances_response import PersonasInstancesResponse
from neurograph.v1.models.personas_kpi import PersonasKpi
from neurograph.v1.models.personas_kpi_create_request import PersonasKpiCreateRequest
from neurograph.v1.models.personas_kpi_create_response import PersonasKpiCreateResponse
from neurograph.v1.models.personas_kpi_req_row import PersonasKpiReqRow
from neurograph.v1.models.personas_kpi_row_in_db import PersonasKpiRowInDb
from neurograph.v1.models.personas_match_criteria_delete_response import PersonasMatchCriteriaDeleteResponse
from neurograph.v1.models.personas_match_criteria_reorder_item import PersonasMatchCriteriaReorderItem
from neurograph.v1.models.personas_match_criteria_reorder_request import PersonasMatchCriteriaReorderRequest
from neurograph.v1.models.personas_match_criteria_reorder_response import PersonasMatchCriteriaReorderResponse
from neurograph.v1.models.personas_match_criteria_request import PersonasMatchCriteriaRequest
from neurograph.v1.models.personas_match_criteria_response import PersonasMatchCriteriaResponse
from neurograph.v1.models.personas_match_criteria_row_in import PersonasMatchCriteriaRowIn
from neurograph.v1.models.personas_match_criteria_row_in_db import PersonasMatchCriteriaRowInDb
from neurograph.v1.models.personas_match_criteria_update_request import PersonasMatchCriteriaUpdateRequest
from neurograph.v1.models.personas_match_criteria_update_response import PersonasMatchCriteriaUpdateResponse
from neurograph.v1.models.personas_persona import PersonasPersona
from neurograph.v1.models.personas_persona_factor import PersonasPersonaFactor
from neurograph.v1.models.personas_persona_insight import PersonasPersonaInsight
from neurograph.v1.models.personas_persona_personality_trait import PersonasPersonaPersonalityTrait
from neurograph.v1.models.personas_personality_trait_create_request import PersonasPersonalityTraitCreateRequest
from neurograph.v1.models.personas_personality_trait_create_response import PersonasPersonalityTraitCreateResponse
from neurograph.v1.models.personas_personality_trait_in_db import PersonasPersonalityTraitInDb
from neurograph.v1.models.personas_personality_trait_req import PersonasPersonalityTraitReq
from neurograph.v1.models.personas_seed import PersonasSeed
from neurograph.v1.models.personas_seed_get_many_response import PersonasSeedGetManyResponse
from neurograph.v1.models.personas_seed_upsert_request import PersonasSeedUpsertRequest
from neurograph.v1.models.personas_seeds_delete_response import PersonasSeedsDeleteResponse
from neurograph.v1.models.personas_supplemental_prompt_create_request import PersonasSupplementalPromptCreateRequest
from neurograph.v1.models.personas_supplemental_prompt_delete_response import PersonasSupplementalPromptDeleteResponse
from neurograph.v1.models.personas_supplemental_prompt_get_many_response import PersonasSupplementalPromptGetManyResponse
from neurograph.v1.models.personas_supplemental_prompt_response import PersonasSupplementalPromptResponse
from neurograph.v1.models.personas_supplemental_prompt_status_update_request import PersonasSupplementalPromptStatusUpdateRequest
from neurograph.v1.models.personas_update_demographics_request import PersonasUpdateDemographicsRequest
from neurograph.v1.models.personas_update_demographics_response import PersonasUpdateDemographicsResponse
from neurograph.v1.models.personas_update_display_info_request import PersonasUpdateDisplayInfoRequest
from neurograph.v1.models.personas_update_display_info_response import PersonasUpdateDisplayInfoResponse
from neurograph.v1.models.pgtype_bool import PgtypeBool
from neurograph.v1.models.pgtype_infinity_modifier import PgtypeInfinityModifier
from neurograph.v1.models.pgtype_int4 import PgtypeInt4
from neurograph.v1.models.pgtype_int8 import PgtypeInt8
from neurograph.v1.models.pgtype_text import PgtypeText
from neurograph.v1.models.pgtype_timestamp import PgtypeTimestamp
from neurograph.v1.models.pgtype_timestamptz import PgtypeTimestamptz
from neurograph.v1.models.pixel_client_info import PixelClientInfo
from neurograph.v1.models.pixel_client_pixel_details_request import PixelClientPixelDetailsRequest
from neurograph.v1.models.pixel_client_pixel_details_response import PixelClientPixelDetailsResponse
from neurograph.v1.models.pixel_client_pixel_summary import PixelClientPixelSummary
from neurograph.v1.models.pixel_client_pixel_totals import PixelClientPixelTotals
from neurograph.v1.models.pixel_daily_client_pixel_metrics import PixelDailyClientPixelMetrics
from neurograph.v1.models.pixel_daily_pixel_metrics import PixelDailyPixelMetrics
from neurograph.v1.models.pixel_date_range import PixelDateRange
from neurograph.v1.models.pixel_enrichment_coverage import PixelEnrichmentCoverage
from neurograph.v1.models.pixel_pixel_overview_request import PixelPixelOverviewRequest
from neurograph.v1.models.pixel_pixel_overview_response import PixelPixelOverviewResponse
from neurograph.v1.models.pixel_pixel_overview_totals import PixelPixelOverviewTotals
from neurograph.v1.models.reporting_activity_metrics import ReportingActivityMetrics
from neurograph.v1.models.reporting_affinity_debug_info import ReportingAffinityDebugInfo
from neurograph.v1.models.reporting_affinity_meta import ReportingAffinityMeta
from neurograph.v1.models.reporting_age_breakdown_row import ReportingAgeBreakdownRow
from neurograph.v1.models.reporting_age_bucket import ReportingAgeBucket
from neurograph.v1.models.reporting_age_distribution_data import ReportingAgeDistributionData
from neurograph.v1.models.reporting_buyer_scenario import ReportingBuyerScenario
from neurograph.v1.models.reporting_buyer_scenarios_meta import ReportingBuyerScenariosMeta
from neurograph.v1.models.reporting_category_performance_data import ReportingCategoryPerformanceData
from neurograph.v1.models.reporting_category_performance_row import ReportingCategoryPerformanceRow
from neurograph.v1.models.reporting_category_spend_data import ReportingCategorySpendData
from neurograph.v1.models.reporting_category_spend_week import ReportingCategorySpendWeek
from neurograph.v1.models.reporting_category_summary import ReportingCategorySummary
from neurograph.v1.models.reporting_clear_cache_request import ReportingClearCacheRequest
from neurograph.v1.models.reporting_clear_cache_response import ReportingClearCacheResponse
from neurograph.v1.models.reporting_client_activity_event import ReportingClientActivityEvent
from neurograph.v1.models.reporting_client_activity_query import ReportingClientActivityQuery
from neurograph.v1.models.reporting_client_activity_summary import ReportingClientActivitySummary
from neurograph.v1.models.reporting_client_breakdown import ReportingClientBreakdown
from neurograph.v1.models.reporting_client_enrichment_coverage import ReportingClientEnrichmentCoverage
from neurograph.v1.models.reporting_combined_activity_response import ReportingCombinedActivityResponse
from neurograph.v1.models.reporting_computed_metrics import ReportingComputedMetrics
from neurograph.v1.models.reporting_customer_cycle_metrics import ReportingCustomerCycleMetrics
from neurograph.v1.models.reporting_customer_gender_split_data import ReportingCustomerGenderSplitData
from neurograph.v1.models.reporting_customer_insights_request import ReportingCustomerInsightsRequest
from neurograph.v1.models.reporting_customer_insights_response import ReportingCustomerInsightsResponse
from neurograph.v1.models.reporting_cycle_summary import ReportingCycleSummary
from neurograph.v1.models.reporting_cycle_tiers import ReportingCycleTiers
from neurograph.v1.models.reporting_daily_metric import ReportingDailyMetric
from neurograph.v1.models.reporting_daily_metrics_response import ReportingDailyMetricsResponse
from neurograph.v1.models.reporting_daily_predictions import ReportingDailyPredictions
from neurograph.v1.models.reporting_daily_rollup_debug_info import ReportingDailyRollupDebugInfo
from neurograph.v1.models.reporting_daily_summary import ReportingDailySummary
from neurograph.v1.models.reporting_daily_total import ReportingDailyTotal
from neurograph.v1.models.reporting_data_availability_query import ReportingDataAvailabilityQuery
from neurograph.v1.models.reporting_data_availability_response import ReportingDataAvailabilityResponse
from neurograph.v1.models.reporting_date_range import ReportingDateRange
from neurograph.v1.models.reporting_debug_query import ReportingDebugQuery
from neurograph.v1.models.reporting_demographics_debug_info import ReportingDemographicsDebugInfo
from neurograph.v1.models.reporting_demographics_meta import ReportingDemographicsMeta
from neurograph.v1.models.reporting_enrichment_coverage_query import ReportingEnrichmentCoverageQuery
from neurograph.v1.models.reporting_enrichment_coverage_response import ReportingEnrichmentCoverageResponse
from neurograph.v1.models.reporting_enrichment_coverage_summary import ReportingEnrichmentCoverageSummary
from neurograph.v1.models.reporting_gender_split_data import ReportingGenderSplitData
from neurograph.v1.models.reporting_geographic_distribution_data import ReportingGeographicDistributionData
from neurograph.v1.models.reporting_income_band import ReportingIncomeBand
from neurograph.v1.models.reporting_income_bands_data import ReportingIncomeBandsData
from neurograph.v1.models.reporting_intent_band_data import ReportingIntentBandData
from neurograph.v1.models.reporting_metro_area import ReportingMetroArea
from neurograph.v1.models.reporting_model_insights_request import ReportingModelInsightsRequest
from neurograph.v1.models.reporting_model_insights_response import ReportingModelInsightsResponse
from neurograph.v1.models.reporting_model_job_detail import ReportingModelJobDetail
from neurograph.v1.models.reporting_model_job_detail_response import ReportingModelJobDetailResponse
from neurograph.v1.models.reporting_model_job_stats import ReportingModelJobStats
from neurograph.v1.models.reporting_model_job_summary import ReportingModelJobSummary
from neurograph.v1.models.reporting_model_jobs_over_time import ReportingModelJobsOverTime
from neurograph.v1.models.reporting_model_prediction import ReportingModelPrediction
from neurograph.v1.models.reporting_model_version_stats import ReportingModelVersionStats
from neurograph.v1.models.reporting_org_breakdown import ReportingOrgBreakdown
from neurograph.v1.models.reporting_other_markets import ReportingOtherMarkets
from neurograph.v1.models.reporting_period_comparison import ReportingPeriodComparison
from neurograph.v1.models.reporting_persona_buyer_scenarios_request import ReportingPersonaBuyerScenariosRequest
from neurograph.v1.models.reporting_persona_buyer_scenarios_response import ReportingPersonaBuyerScenariosResponse
from neurograph.v1.models.reporting_persona_demographics_request import ReportingPersonaDemographicsRequest
from neurograph.v1.models.reporting_persona_demographics_response import ReportingPersonaDemographicsResponse
from neurograph.v1.models.reporting_persona_product_affinity_request import ReportingPersonaProductAffinityRequest
from neurograph.v1.models.reporting_persona_product_affinity_response import ReportingPersonaProductAffinityResponse
from neurograph.v1.models.reporting_portfolio_activity_query import ReportingPortfolioActivityQuery
from neurograph.v1.models.reporting_portfolio_activity_response import ReportingPortfolioActivityResponse
from neurograph.v1.models.reporting_portfolio_metrics import ReportingPortfolioMetrics
from neurograph.v1.models.reporting_prediction_detail import ReportingPredictionDetail
from neurograph.v1.models.reporting_prediction_detail_response import ReportingPredictionDetailResponse
from neurograph.v1.models.reporting_price_bucket import ReportingPriceBucket
from neurograph.v1.models.reporting_price_tolerance_data import ReportingPriceToleranceData
from neurograph.v1.models.reporting_product_affinity_query_request import ReportingProductAffinityQueryRequest
from neurograph.v1.models.reporting_product_affinity_response import ReportingProductAffinityResponse
from neurograph.v1.models.reporting_product_affinity_row import ReportingProductAffinityRow
from neurograph.v1.models.reporting_product_performance_data import ReportingProductPerformanceData
from neurograph.v1.models.reporting_product_performance_row import ReportingProductPerformanceRow
from neurograph.v1.models.reporting_purchase_cycle_data import ReportingPurchaseCycleData
from neurograph.v1.models.reporting_purchase_timing_data import ReportingPurchaseTimingData
from neurograph.v1.models.reporting_purchases_response import ReportingPurchasesResponse
from neurograph.v1.models.reporting_query import ReportingQuery
from neurograph.v1.models.reporting_scenario_market_concept import ReportingScenarioMarketConcept
from neurograph.v1.models.reporting_scenario_path import ReportingScenarioPath
from neurograph.v1.models.reporting_scenario_product import ReportingScenarioProduct
from neurograph.v1.models.reporting_sessions_response import ReportingSessionsResponse
from neurograph.v1.models.reporting_summary_kpis import ReportingSummaryKPIs
from neurograph.v1.models.reporting_timing_bucket import ReportingTimingBucket
from neurograph.v1.models.reporting_traffic_pipeline_day import ReportingTrafficPipelineDay
from neurograph.v1.models.reporting_traffic_trend_day import ReportingTrafficTrendDay
from neurograph.v1.models.reports_data_source_config import ReportsDataSourceConfig
from neurograph.v1.models.reports_date_range import ReportsDateRange
from neurograph.v1.models.reports_facet_item import ReportsFacetItem
from neurograph.v1.models.reports_generate_summary_request import ReportsGenerateSummaryRequest
from neurograph.v1.models.reports_linked_kpi import ReportsLinkedKPI
from neurograph.v1.models.reports_linked_query import ReportsLinkedQuery
from neurograph.v1.models.reports_markdown_content_response import ReportsMarkdownContentResponse
from neurograph.v1.models.reports_markdown_content_update_request import ReportsMarkdownContentUpdateRequest
from neurograph.v1.models.reports_og_image_regenerate_response import ReportsOGImageRegenerateResponse
from neurograph.v1.models.reports_public_branding import ReportsPublicBranding
from neurograph.v1.models.reports_public_report_response import ReportsPublicReportResponse
from neurograph.v1.models.reports_publish_completion_request import ReportsPublishCompletionRequest
from neurograph.v1.models.reports_publish_completion_response import ReportsPublishCompletionResponse
from neurograph.v1.models.reports_recommendation import ReportsRecommendation
from neurograph.v1.models.reports_report_agent_status_response import ReportsReportAgentStatusResponse
from neurograph.v1.models.reports_report_artifact_create_request import ReportsReportArtifactCreateRequest
from neurograph.v1.models.reports_report_artifact_delete_response import ReportsReportArtifactDeleteResponse
from neurograph.v1.models.reports_report_artifact_list_response import ReportsReportArtifactListResponse
from neurograph.v1.models.reports_report_artifact_response import ReportsReportArtifactResponse
from neurograph.v1.models.reports_report_artifact_search_response import ReportsReportArtifactSearchResponse
from neurograph.v1.models.reports_report_artifact_update_request import ReportsReportArtifactUpdateRequest
from neurograph.v1.models.reports_report_facets_response import ReportsReportFacetsResponse
from neurograph.v1.models.reports_report_generate_request import ReportsReportGenerateRequest
from neurograph.v1.models.reports_report_generate_response import ReportsReportGenerateResponse
from neurograph.v1.models.reports_share_link_response import ReportsShareLinkResponse
from neurograph.v1.models.reports_sync_agent_request import ReportsSyncAgentRequest
from neurograph.v1.models.reports_sync_agent_response import ReportsSyncAgentResponse
from neurograph.v1.models.shopify_associate_store_request import ShopifyAssociateStoreRequest
from neurograph.v1.models.shopify_get_store_response import ShopifyGetStoreResponse
from neurograph.v1.models.shopify_get_unmatched_stores_response import ShopifyGetUnmatchedStoresResponse
from neurograph.v1.models.shopify_store_detail import ShopifyStoreDetail
from neurograph.v1.models.shopify_store_query import ShopifyStoreQuery
from neurograph.v1.models.shopify_store_summary import ShopifyStoreSummary
from neurograph.v1.models.signal_client_info import SignalClientInfo
from neurograph.v1.models.signal_client_signal_details_request import SignalClientSignalDetailsRequest
from neurograph.v1.models.signal_client_signal_details_response import SignalClientSignalDetailsResponse
from neurograph.v1.models.signal_client_signal_summary import SignalClientSignalSummary
from neurograph.v1.models.signal_client_signal_totals import SignalClientSignalTotals
from neurograph.v1.models.signal_conversion_summary import SignalConversionSummary
from neurograph.v1.models.signal_conversion_totals import SignalConversionTotals
from neurograph.v1.models.signal_daily_conversion_metrics import SignalDailyConversionMetrics
from neurograph.v1.models.signal_daily_intent_band import SignalDailyIntentBand
from neurograph.v1.models.signal_daily_intent_metrics import SignalDailyIntentMetrics
from neurograph.v1.models.signal_daily_purchase_metrics import SignalDailyPurchaseMetrics
from neurograph.v1.models.signal_date_range import SignalDateRange
from neurograph.v1.models.signal_intent_distribution import SignalIntentDistribution
from neurograph.v1.models.signal_intent_summary import SignalIntentSummary
from neurograph.v1.models.signal_persona_conversion import SignalPersonaConversion
from neurograph.v1.models.signal_signal_overview_request import SignalSignalOverviewRequest
from neurograph.v1.models.signal_signal_overview_response import SignalSignalOverviewResponse
from neurograph.v1.models.signal_signal_overview_totals import SignalSignalOverviewTotals
from neurograph.v1.models.utils_color_pair_result import UtilsColorPairResult
from neurograph.v1.models.utils_validation_error import UtilsValidationError
from neurograph.v1.models.utils_validation_errors import UtilsValidationErrors
from neurograph.v1.models.workbench_workbench_url_check_request import WorkbenchWorkbenchUrlCheckRequest
from neurograph.v1.models.workbench_workbench_url_check_response import WorkbenchWorkbenchUrlCheckResponse
from neurograph.v1.models.workbench_workbench_version import WorkbenchWorkbenchVersion
from neurograph.v1.models.workbench_workbench_version_many_response import WorkbenchWorkbenchVersionManyResponse
from neurograph.v1.models.workbench_workbench_version_response import WorkbenchWorkbenchVersionResponse
from neurograph.v1.models.workbench_workbench_version_upsert_request import WorkbenchWorkbenchVersionUpsertRequest




# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_product_affinity_response import ReportingProductAffinityResponse

class TestReportingProductAffinityResponse(unittest.TestCase):
    """ReportingProductAffinityResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingProductAffinityResponse:
        """Test ReportingProductAffinityResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingProductAffinityResponse`
        """
        model = ReportingProductAffinityResponse()
        if include_optional:
            return ReportingProductAffinityResponse(
                cached = True,
                data = [
                    neurograph.v1.models.reporting/product_affinity_row.reporting.ProductAffinityRow(
                        avg_engagement_score = 1.337, 
                        avg_lifetime_value = 1.337, 
                        avg_view_count = 1.337, 
                        client_partition_key = '', 
                        confidence_level = 56, 
                        conversion_rate = 1.337, 
                        entity_id = '', 
                        normalized_affinity_score = 1.337, 
                        partition_date = '', 
                        product_handle = '', 
                        product_id = '', 
                        product_name = '', 
                        product_type = '', 
                        raw_affinity_score = 1.337, 
                        score_penalty = 1.337, 
                        total_conversions = 56, 
                        total_visitors = 56, 
                        weighted_conversion_score = 1.337, )
                    ],
                error = '',
                query_time_ms = 56
            )
        else:
            return ReportingProductAffinityResponse(
        )
        """

    def testReportingProductAffinityResponse(self):
        """Test ReportingProductAffinityResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reports_report_artifact_response import ReportsReportArtifactResponse

class TestReportsReportArtifactResponse(unittest.TestCase):
    """ReportsReportArtifactResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportsReportArtifactResponse:
        """Test ReportsReportArtifactResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportsReportArtifactResponse`
        """
        model = ReportsReportArtifactResponse()
        if include_optional:
            return ReportsReportArtifactResponse(
                ai_call_to_action = '',
                ai_generated_at = '',
                ai_key_highlights = [
                    ''
                    ],
                ai_main_insights = [
                    ''
                    ],
                client_id = 'cli_abc',
                created_by = '',
                description = '',
                embed_url = 'https://gamma.app/embed/...',
                error = '',
                executive_summary = '',
                id = '',
                key_stats = [
                    56
                    ],
                linked_concepts = [
                    ''
                    ],
                linked_kpis = [
                    neurograph.v1.models.reports/linked_kpi.reports.LinkedKPI(
                        change = '+0.4%', 
                        kpi_id = 'kpi_12345', 
                        kpi_name = 'Conversion Rate', 
                        trend = 'up', 
                        value = '3.2%', )
                    ],
                linked_queries = [
                    neurograph.v1.models.reports/linked_query.reports.LinkedQuery(
                        description = 'Products with highest conversion in Q4', 
                        query_id = 'qry_67890', 
                        query_name = 'Top Converting Products', )
                    ],
                linked_themes = [
                    ''
                    ],
                linked_topics = [
                    ''
                    ],
                markdown_content = '',
                markdown_updated_at = '',
                markdown_updated_by = '',
                metadata = [
                    56
                    ],
                name = 'Q4 2024 Persona Analysis',
                og_image_generated_at = '',
                og_image_url = '',
                og_image_version = 56,
                organization_id = '',
                pdf_url = '',
                presentation_url = 'https://gamma.app/docs/...',
                recommendations = [
                    neurograph.v1.models.reports/recommendation.reports.Recommendation(
                        action_url = '/campaigns/create?segment=a', 
                        category = 'engagement', 
                        id = '', 
                        priority = 'high', 
                        title = 'Increase email frequency for Segment A', )
                    ],
                report_type = 'monthly_persona_readout',
                thumbnail_url = '',
                ts_created = '',
                ts_updated = '',
                updated_by = ''
            )
        else:
            return ReportsReportArtifactResponse(
        )
        """

    def testReportsReportArtifactResponse(self):
        """Test ReportsReportArtifactResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.reporting_affinity_debug_info import ReportingAffinityDebugInfo
from neurograph.v1.models.reporting_affinity_meta import ReportingAffinityMeta
from neurograph.v1.models.reporting_category_performance_data import ReportingCategoryPerformanceData
from neurograph.v1.models.reporting_category_spend_data import ReportingCategorySpendData
from neurograph.v1.models.reporting_price_tolerance_data import ReportingPriceToleranceData
from neurograph.v1.models.reporting_product_performance_data import ReportingProductPerformanceData
from neurograph.v1.models.reporting_purchase_cycle_data import ReportingPurchaseCycleData
from neurograph.v1.models.reporting_purchase_timing_data import ReportingPurchaseTimingData
from typing import Optional, Set
from typing_extensions import Self

class ReportingPersonaProductAffinityResponse(BaseModel):
    """
    ReportingPersonaProductAffinityResponse
    """ # noqa: E501
    cached: Optional[StrictBool] = None
    category_performance: Optional[ReportingCategoryPerformanceData] = None
    category_spend: Optional[ReportingCategorySpendData] = None
    debug_info: Optional[ReportingAffinityDebugInfo] = None
    error: Optional[StrictStr] = None
    meta: Optional[ReportingAffinityMeta] = None
    no_data: Optional[StrictBool] = None
    price_tolerance: Optional[ReportingPriceToleranceData] = None
    product_performance: Optional[ReportingProductPerformanceData] = None
    purchase_cycle: Optional[ReportingPurchaseCycleData] = None
    purchase_timing: Optional[ReportingPurchaseTimingData] = None
    query_time_ms: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["cached", "category_performance", "category_spend", "debug_info", "error", "meta", "no_data", "price_tolerance", "product_performance", "purchase_cycle", "purchase_timing", "query_time_ms"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportingPersonaProductAffinityResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of category_performance
        if self.category_performance:
            _dict['category_performance'] = self.category_performance.to_dict()
        # override the default output from pydantic by calling `to_dict()` of category_spend
        if self.category_spend:
            _dict['category_spend'] = self.category_spend.to_dict()
        # override the default output from pydantic by calling `to_dict()` of debug_info
        if self.debug_info:
            _dict['debug_info'] = self.debug_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of meta
        if self.meta:
            _dict['meta'] = self.meta.to_dict()
        # override the default output from pydantic by calling `to_dict()` of price_tolerance
        if self.price_tolerance:
            _dict['price_tolerance'] = self.price_tolerance.to_dict()
        # override the default output from pydantic by calling `to_dict()` of product_performance
        if self.product_performance:
            _dict['product_performance'] = self.product_performance.to_dict()
        # override the default output from pydantic by calling `to_dict()` of purchase_cycle
        if self.purchase_cycle:
            _dict['purchase_cycle'] = self.purchase_cycle.to_dict()
        # override the default output from pydantic by calling `to_dict()` of purchase_timing
        if self.purchase_timing:
            _dict['purchase_timing'] = self.purchase_timing.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportingPersonaProductAffinityResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "cached": obj.get("cached"),
            "category_performance": ReportingCategoryPerformanceData.from_dict(obj["category_performance"]) if obj.get("category_performance") is not None else None,
            "category_spend": ReportingCategorySpendData.from_dict(obj["category_spend"]) if obj.get("category_spend") is not None else None,
            "debug_info": ReportingAffinityDebugInfo.from_dict(obj["debug_info"]) if obj.get("debug_info") is not None else None,
            "error": obj.get("error"),
            "meta": ReportingAffinityMeta.from_dict(obj["meta"]) if obj.get("meta") is not None else None,
            "no_data": obj.get("no_data"),
            "price_tolerance": ReportingPriceToleranceData.from_dict(obj["price_tolerance"]) if obj.get("price_tolerance") is not None else None,
            "product_performance": ReportingProductPerformanceData.from_dict(obj["product_performance"]) if obj.get("product_performance") is not None else None,
            "purchase_cycle": ReportingPurchaseCycleData.from_dict(obj["purchase_cycle"]) if obj.get("purchase_cycle") is not None else None,
            "purchase_timing": ReportingPurchaseTimingData.from_dict(obj["purchase_timing"]) if obj.get("purchase_timing") is not None else None,
            "query_time_ms": obj.get("query_time_ms")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.personas_persona import PersonasPersona

class TestPersonasPersona(unittest.TestCase):
    """PersonasPersona unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PersonasPersona:
        """Test PersonasPersona
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PersonasPersona`
        """
        model = PersonasPersona()
        if include_optional:
            return PersonasPersona(
                age = 1.337,
                description = '',
                factors = [
                    neurograph.v1.models.personas/persona_factor.personas.PersonaFactor(
                        detail = '', 
                        display = '', 
                        id = 56, 
                        name = '', 
                        persona_instance_id = '', 
                        summary = '', 
                        value = 56, )
                    ],
                female = 1.337,
                id = '',
                income = '',
                insights = [
                    neurograph.v1.models.personas/persona_insight.personas.PersonaInsight(
                        data = neurograph.v1.models.data.data(), 
                        id = 56, 
                        key = '', 
                        persona_instance_id = 56, )
                    ],
                kpis = [
                    neurograph.v1.models.personas/kpi.personas.Kpi(
                        id = 56, 
                        name = '', 
                        persona_instance_id = '', 
                        value = '', )
                    ],
                male = 1.337,
                match_criteria = [
                    neurograph.v1.models.personas/match_criteria_row_in_db.personas.MatchCriteriaRowInDb(
                        concept = '', 
                        detail = '', 
                        display = '', 
                        error = '', 
                        id = 56, 
                        persona_instance_id = '', 
                        sort_order = 56, )
                    ],
                metadata = '',
                name = '',
                persona_seed_id = '',
                personality_background = '',
                personality_first_name = '',
                personality_gender = '',
                personality_img_url = '',
                personality_last_name = '',
                personality_quote = '',
                personality_traits = [
                    neurograph.v1.models.personas/persona_personality_trait.personas.PersonaPersonalityTrait(
                        id = 56, 
                        name = '', 
                        persona_instance_id = '', 
                        traits = [
                            ''
                            ], )
                    ],
                personality_video_url = '',
                positioning_statement = '',
                seed_uid = '',
                summary_detail = '',
                summary_headline = '',
                tag = '',
                ts_created = 56,
                ts_updated = 56,
                value = ''
            )
        else:
            return PersonasPersona(
        )
        """

    def testPersonasPersona(self):
        """Test PersonasPersona"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ReportingClearCacheRequest(BaseModel):
    """
    ReportingClearCacheRequest
    """ # noqa: E501
    client_partition_key: Optional[StrictStr] = Field(default=None, description="ClientPartitionKey: org_uid + client_uid + domain")
    persona_id: Optional[StrictStr] = Field(default=None, description="PersonaId: the persona seed ID (per_...) to clear caches for")
    query_type: Optional[StrictStr] = Field(default=None, description="QueryType: specific cache to clear (only used when scope=query) Options: persona-affinity, persona-demographics, buyer-scenarios, customer-insights,          product-affinity, enrichment-coverage, model-insights, model-job-detail,          prediction-detail, client-activity, daily-rollup, portfolio-activity, all")
    scope: Optional[StrictStr] = Field(default=None, description="Scope: \"persona\" clears all caches for a persona, \"query\" clears a specific query type")
    __properties: ClassVar[List[str]] = ["client_partition_key", "persona_id", "query_type", "scope"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportingClearCacheRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportingClearCacheRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "client_partition_key": obj.get("client_partition_key"),
            "persona_id": obj.get("persona_id"),
            "query_type": obj.get("query_type"),
            "scope": obj.get("scope")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_persona_assignment_stats_response import ClientPersonaAssignmentStatsResponse

class TestClientPersonaAssignmentStatsResponse(unittest.TestCase):
    """ClientPersonaAssignmentStatsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientPersonaAssignmentStatsResponse:
        """Test ClientPersonaAssignmentStatsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientPersonaAssignmentStatsResponse`
        """
        model = ClientPersonaAssignmentStatsResponse()
        if include_optional:
            return ClientPersonaAssignmentStatsResponse(
                data = [
                    neurograph.v1.models.client/persona_assignment_stats.client.PersonaAssignmentStats(
                        first_assignment_date = '', 
                        last_assignment_date = '', 
                        persona_id = '', 
                        persona_name = '', 
                        total_assignments = 56, )
                    ],
                error = ''
            )
        else:
            return ClientPersonaAssignmentStatsResponse(
        )
        """

    def testClientPersonaAssignmentStatsResponse(self):
        """Test ClientPersonaAssignmentStatsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.reporting_daily_total import ReportingDailyTotal
from neurograph.v1.models.reporting_intent_band_data import ReportingIntentBandData
from typing import Optional, Set
from typing_extensions import Self

class ReportingTrafficPipelineDay(BaseModel):
    """
    ReportingTrafficPipelineDay
    """ # noqa: E501
    daily_total: Optional[ReportingDailyTotal] = None
    var_date: Optional[StrictStr] = Field(default=None, alias="date")
    intent_bands: Optional[Dict[str, ReportingIntentBandData]] = None
    __properties: ClassVar[List[str]] = ["daily_total", "date", "intent_bands"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportingTrafficPipelineDay from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of daily_total
        if self.daily_total:
            _dict['daily_total'] = self.daily_total.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each value in intent_bands (dict)
        _field_dict = {}
        if self.intent_bands:
            for _key_intent_bands in self.intent_bands:
                if self.intent_bands[_key_intent_bands]:
                    _field_dict[_key_intent_bands] = self.intent_bands[_key_intent_bands].to_dict()
            _dict['intent_bands'] = _field_dict
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportingTrafficPipelineDay from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "daily_total": ReportingDailyTotal.from_dict(obj["daily_total"]) if obj.get("daily_total") is not None else None,
            "date": obj.get("date"),
            "intent_bands": dict(
                (_k, ReportingIntentBandData.from_dict(_v))
                for _k, _v in obj["intent_bands"].items()
            )
            if obj.get("intent_bands") is not None
            else None
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_combined_activity_response import ReportingCombinedActivityResponse

class TestReportingCombinedActivityResponse(unittest.TestCase):
    """ReportingCombinedActivityResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingCombinedActivityResponse:
        """Test ReportingCombinedActivityResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingCombinedActivityResponse`
        """
        model = ReportingCombinedActivityResponse()
        if include_optional:
            return ReportingCombinedActivityResponse(
                cached = True,
                error = '',
                purchases = neurograph.v1.models.reporting/activity_metrics.reporting.ActivityMetrics(
                    summary = [
                        neurograph.v1.models.reporting/client_activity_summary.reporting.ClientActivitySummary(
                            count = 56, 
                            date = '', )
                        ], 
                    total = 56, ),
                sessions = neurograph.v1.models.reporting/activity_metrics.reporting.ActivityMetrics(
                    summary = [
                        neurograph.v1.models.reporting/client_activity_summary.reporting.ClientActivitySummary(
                            count = 56, 
                            date = '', )
                        ], 
                    total = 56, )
            )
        else:
            return ReportingCombinedActivityResponse(
        )
        """

    def testReportingCombinedActivityResponse(self):
        """Test ReportingCombinedActivityResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_purchases_response import ReportingPurchasesResponse

class TestReportingPurchasesResponse(unittest.TestCase):
    """ReportingPurchasesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPurchasesResponse:
        """Test ReportingPurchasesResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPurchasesResponse`
        """
        model = ReportingPurchasesResponse()
        if include_optional:
            return ReportingPurchasesResponse(
                cached = True,
                data = [
                    neurograph.v1.models.reporting/client_activity_event.reporting.ClientActivityEvent(
                        browser_ip = '', 
                        client_id = '', 
                        distinct_id = '', 
                        hem = '', 
                        order_id = '', 
                        timestamp = '', 
                        visit_city = '', 
                        visit_state = '', 
                        visit_state_code = '', )
                    ],
                error = '',
                summary = [
                    neurograph.v1.models.reporting/client_activity_summary.reporting.ClientActivitySummary(
                        count = 56, 
                        date = '', )
                    ],
                total = 56
            )
        else:
            return ReportingPurchasesResponse(
        )
        """

    def testReportingPurchasesResponse(self):
        """Test ReportingPurchasesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.pixel_pixel_overview_response import PixelPixelOverviewResponse

class TestPixelPixelOverviewResponse(unittest.TestCase):
    """PixelPixelOverviewResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PixelPixelOverviewResponse:
        """Test PixelPixelOverviewResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PixelPixelOverviewResponse`
        """
        model = PixelPixelOverviewResponse()
        if include_optional:
            return PixelPixelOverviewResponse(
                by_client = [
                    neurograph.v1.models.pixel/client_pixel_summary.pixel.ClientPixelSummary(
                        avg_enrichment_rate_pct = 1.337, 
                        avg_match_rate_pct = 1.337, 
                        client_uid = '', 
                        estimated_cost = 1.337, 
                        org_uid = '', 
                        temporal_matches = 56, 
                        total_enriched = 56, 
                        total_matched = 56, 
                        total_sessions = 56, 
                        total_visitors = 56, 
                        vendor_matches = 56, )
                    ],
                cached = True,
                daily_metrics = [
                    neurograph.v1.models.pixel/daily_pixel_metrics.pixel.DailyPixelMetrics(
                        date = '', 
                        enriched_visitors = 56, 
                        enrichment_rate_pct = 1.337, 
                        match_rate_pct = 1.337, 
                        matched_hems = 56, 
                        sessions_per_visitor = 1.337, 
                        total_sessions = 56, 
                        unique_visitors = 56, )
                    ],
                date_range = neurograph.v1.models.pixel/date_range.pixel.DateRange(
                    end_date = '', 
                    start_date = '', ),
                error = '',
                query_time_ms = 56,
                totals = neurograph.v1.models.pixel/pixel_overview_totals.pixel.PixelOverviewTotals(
                    avg_enrichment_rate_pct = 1.337, 
                    avg_match_rate_pct = 1.337, 
                    total_enriched = 56, 
                    total_estimated_cost = 1.337, 
                    total_matched = 56, 
                    total_sessions = 56, 
                    total_visitors = 56, )
            )
        else:
            return PixelPixelOverviewResponse(
        )
        """

    def testPixelPixelOverviewResponse(self):
        """Test PixelPixelOverviewResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.db_account_organization_brand import DbAccountOrganizationBrand

class TestDbAccountOrganizationBrand(unittest.TestCase):
    """DbAccountOrganizationBrand unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DbAccountOrganizationBrand:
        """Test DbAccountOrganizationBrand
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DbAccountOrganizationBrand`
        """
        model = DbAccountOrganizationBrand()
        if include_optional:
            return DbAccountOrganizationBrand(
                accessibility_level = neurograph.v1.models.pgtype/text.pgtype.Text(
                    string = '', 
                    valid = True, ),
                background_img_url = '',
                color1 = '',
                color2 = '',
                color3 = '',
                color4 = '',
                color5 = '',
                component_config = [
                    56
                    ],
                dark_mode_enabled = neurograph.v1.models.pgtype/bool.pgtype.Bool(
                    bool = True, 
                    valid = True, ),
                generation_metadata = [
                    56
                    ],
                id = 56,
                is_ai_generated = neurograph.v1.models.pgtype/bool.pgtype.Bool(
                    bool = True, 
                    valid = True, ),
                logo_img_url = '',
                org_id = '',
                preset_applied_at = neurograph.v1.models.pgtype/timestamptz.pgtype.Timestamptz(
                    infinity_modifier = 1, 
                    time = '', 
                    valid = True, ),
                preset_customized = neurograph.v1.models.pgtype/bool.pgtype.Bool(
                    bool = True, 
                    valid = True, ),
                preset_id = neurograph.v1.models.pgtype/text.pgtype.Text(
                    string = '', 
                    valid = True, ),
                preset_name = neurograph.v1.models.pgtype/text.pgtype.Text(
                    string = '', 
                    valid = True, ),
                primary_color = '',
                secondary_color = '',
                spacing_config = [
                    56
                    ],
                tertiary_color = '',
                typography_config = [
                    56
                    ],
                version = neurograph.v1.models.pgtype/int4.pgtype.Int4(
                    int32 = 56, 
                    valid = True, )
            )
        else:
            return DbAccountOrganizationBrand(
        )
        """

    def testDbAccountOrganizationBrand(self):
        """Test DbAccountOrganizationBrand"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_assertion_list_response import KnowledgeAssertionListResponse

class TestKnowledgeAssertionListResponse(unittest.TestCase):
    """KnowledgeAssertionListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeAssertionListResponse:
        """Test KnowledgeAssertionListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeAssertionListResponse`
        """
        model = KnowledgeAssertionListResponse()
        if include_optional:
            return KnowledgeAssertionListResponse(
                data = [
                    neurograph.v1.models.knowledge/assertion.knowledge.Assertion(
                        assertion_id = 56, 
                        client_id = '', 
                        confidence = 1.337, 
                        created_at = '', 
                        predicate = '', 
                        source_artifact_id = 56, 
                        source_kind = '', 
                        source_ref = '', 
                        status = '', 
                        subject_entity_id = '', 
                        valid_from = '', 
                        valid_to = '', 
                        value_json = neurograph.v1.models.value_json.value_json(), )
                    ],
                error = '',
                query = neurograph.v1.models.knowledge/assertion_query.knowledge.AssertionQuery(
                    client_id = '', 
                    limit = 56, 
                    offset = 56, 
                    predicate = '', 
                    source_kind = '', 
                    status = '', 
                    subject_entity_id = '', )
            )
        else:
            return KnowledgeAssertionListResponse(
        )
        """

    def testKnowledgeAssertionListResponse(self):
        """Test KnowledgeAssertionListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
